==> zio-aws-cloudfront_2.13-5.19.17.1-sources.jar: zio/aws/cloudfront/model/CustomOriginConfig.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CustomOriginConfig(
    httpPort: Integer,
    httpsPort: Integer,
    originProtocolPolicy: zio.aws.cloudfront.model.OriginProtocolPolicy,
    originSslProtocols: Optional[zio.aws.cloudfront.model.OriginSslProtocols] =
      Optional.Absent,
    originReadTimeout: Optional[Integer] = Optional.Absent,
    originKeepaliveTimeout: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig = {
    import CustomOriginConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
      .builder()
      .httpPort(httpPort: java.lang.Integer)
      .httpsPort(httpsPort: java.lang.Integer)
      .originProtocolPolicy(originProtocolPolicy.unwrap)
      .optionallyWith(originSslProtocols.map(value => value.buildAwsValue()))(
        _.originSslProtocols
      )
      .optionallyWith(originReadTimeout.map(value => value: java.lang.Integer))(
        _.originReadTimeout
      )
      .optionallyWith(
        originKeepaliveTimeout.map(value => value: java.lang.Integer)
      )(_.originKeepaliveTimeout)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.CustomOriginConfig.ReadOnly =
    zio.aws.cloudfront.model.CustomOriginConfig.wrap(buildAwsValue())
}
object CustomOriginConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.CustomOriginConfig =
      zio.aws.cloudfront.model.CustomOriginConfig(
        httpPort,
        httpsPort,
        originProtocolPolicy,
        originSslProtocols.map(value => value.asEditable),
        originReadTimeout.map(value => value),
        originKeepaliveTimeout.map(value => value)
      )
    def httpPort: Integer
    def httpsPort: Integer
    def originProtocolPolicy: zio.aws.cloudfront.model.OriginProtocolPolicy
    def originSslProtocols
        : Optional[zio.aws.cloudfront.model.OriginSslProtocols.ReadOnly]
    def originReadTimeout: Optional[Integer]
    def originKeepaliveTimeout: Optional[Integer]
    def getHttpPort: ZIO[Any, Nothing, Integer] = ZIO.succeed(httpPort)
    def getHttpsPort: ZIO[Any, Nothing, Integer] = ZIO.succeed(httpsPort)
    def getOriginProtocolPolicy
        : ZIO[Any, Nothing, zio.aws.cloudfront.model.OriginProtocolPolicy] =
      ZIO.succeed(originProtocolPolicy)
    def getOriginSslProtocols: ZIO[
      Any,
      AwsError,
      zio.aws.cloudfront.model.OriginSslProtocols.ReadOnly
    ] = AwsError.unwrapOptionField("originSslProtocols", originSslProtocols)
    def getOriginReadTimeout: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("originReadTimeout", originReadTimeout)
    def getOriginKeepaliveTimeout: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("originKeepaliveTimeout", originKeepaliveTimeout)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
  ) extends zio.aws.cloudfront.model.CustomOriginConfig.ReadOnly {
    override val httpPort: Integer = impl.httpPort(): Integer
    override val httpsPort: Integer = impl.httpsPort(): Integer
    override val originProtocolPolicy
        : zio.aws.cloudfront.model.OriginProtocolPolicy =
      zio.aws.cloudfront.model.OriginProtocolPolicy
        .wrap(impl.originProtocolPolicy())
    override val originSslProtocols
        : Optional[zio.aws.cloudfront.model.OriginSslProtocols.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.originSslProtocols())
        .map(value => zio.aws.cloudfront.model.OriginSslProtocols.wrap(value))
    override val originReadTimeout: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.originReadTimeout())
      .map(value => value: Integer)
    override val originKeepaliveTimeout: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.originKeepaliveTimeout())
        .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
  ): zio.aws.cloudfront.model.CustomOriginConfig.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-7.34.1.1-sources.jar: zio/aws/cloudfront/model/CustomOriginConfig.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CustomOriginConfig(
    httpPort: Integer,
    httpsPort: Integer,
    originProtocolPolicy: zio.aws.cloudfront.model.OriginProtocolPolicy,
    originSslProtocols: Optional[zio.aws.cloudfront.model.OriginSslProtocols] =
      Optional.Absent,
    originReadTimeout: Optional[Integer] = Optional.Absent,
    originKeepaliveTimeout: Optional[Integer] = Optional.Absent,
    ipAddressType: Optional[zio.aws.cloudfront.model.IpAddressType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig = {
    import CustomOriginConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
      .builder()
      .httpPort(httpPort: java.lang.Integer)
      .httpsPort(httpsPort: java.lang.Integer)
      .originProtocolPolicy(originProtocolPolicy.unwrap)
      .optionallyWith(originSslProtocols.map(value => value.buildAwsValue()))(
        _.originSslProtocols
      )
      .optionallyWith(originReadTimeout.map(value => value: java.lang.Integer))(
        _.originReadTimeout
      )
      .optionallyWith(
        originKeepaliveTimeout.map(value => value: java.lang.Integer)
      )(_.originKeepaliveTimeout)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.CustomOriginConfig.ReadOnly =
    zio.aws.cloudfront.model.CustomOriginConfig.wrap(buildAwsValue())
}
object CustomOriginConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.CustomOriginConfig =
      zio.aws.cloudfront.model.CustomOriginConfig(
        httpPort,
        httpsPort,
        originProtocolPolicy,
        originSslProtocols.map(value => value.asEditable),
        originReadTimeout.map(value => value),
        originKeepaliveTimeout.map(value => value),
        ipAddressType.map(value => value)
      )
    def httpPort: Integer
    def httpsPort: Integer
    def originProtocolPolicy: zio.aws.cloudfront.model.OriginProtocolPolicy
    def originSslProtocols
        : Optional[zio.aws.cloudfront.model.OriginSslProtocols.ReadOnly]
    def originReadTimeout: Optional[Integer]
    def originKeepaliveTimeout: Optional[Integer]
    def ipAddressType: Optional[zio.aws.cloudfront.model.IpAddressType]
    def getHttpPort: ZIO[Any, Nothing, Integer] = ZIO.succeed(httpPort)
    def getHttpsPort: ZIO[Any, Nothing, Integer] = ZIO.succeed(httpsPort)
    def getOriginProtocolPolicy
        : ZIO[Any, Nothing, zio.aws.cloudfront.model.OriginProtocolPolicy] =
      ZIO.succeed(originProtocolPolicy)
    def getOriginSslProtocols: ZIO[
      Any,
      AwsError,
      zio.aws.cloudfront.model.OriginSslProtocols.ReadOnly
    ] = AwsError.unwrapOptionField("originSslProtocols", originSslProtocols)
    def getOriginReadTimeout: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("originReadTimeout", originReadTimeout)
    def getOriginKeepaliveTimeout: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("originKeepaliveTimeout", originKeepaliveTimeout)
    def getIpAddressType
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.IpAddressType] =
      AwsError.unwrapOptionField("ipAddressType", ipAddressType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
  ) extends zio.aws.cloudfront.model.CustomOriginConfig.ReadOnly {
    override val httpPort: Integer = impl.httpPort(): Integer
    override val httpsPort: Integer = impl.httpsPort(): Integer
    override val originProtocolPolicy
        : zio.aws.cloudfront.model.OriginProtocolPolicy =
      zio.aws.cloudfront.model.OriginProtocolPolicy
        .wrap(impl.originProtocolPolicy())
    override val originSslProtocols
        : Optional[zio.aws.cloudfront.model.OriginSslProtocols.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.originSslProtocols())
        .map(value => zio.aws.cloudfront.model.OriginSslProtocols.wrap(value))
    override val originReadTimeout: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.originReadTimeout())
      .map(value => value: Integer)
    override val originKeepaliveTimeout: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.originKeepaliveTimeout())
        .map(value => value: Integer)
    override val ipAddressType
        : Optional[zio.aws.cloudfront.model.IpAddressType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipAddressType())
        .map(value => zio.aws.cloudfront.model.IpAddressType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.CustomOriginConfig
  ): zio.aws.cloudfront.model.CustomOriginConfig.ReadOnly = new Wrapper(impl)
}
